var request = require('request');
var requestString;
var bootstrapData;
var accessToken;
var querystring = require('querystring');
var configs = require('./configs');
var cache = {};
var proxyApi = require('proxy-api');

function setAccessToken(data)
{
	accessToken = data;
}

function setBootstrapData(data)
{
	bootstrapData = data;
}

function formRequestFromConfig(){
	var conf = configs.get('api');

	var client_secret = conf.client_secret;

	var paramsString = querystring.stringify({
		client_id: conf.client_id,
		client_secret: conf.client_secret,
		grant_type: conf.grant_type
	});
	requestString = conf.secret_url + "?" + paramsString;
}

function getRequestString() {
		
	if (!requestString) {
		formRequestFromConfig();
	};
	return requestString;

}

var Bootstrap = {

	setCacheService: function(cacheService)
	{
		cache = cacheService;
		// console.log(cache);
	},

	getBootstrapData: function()
	{
		return bootstrapData;
	},

	getAccessToken: function()
	{
		return accessToken;
	},

	init: function(callback)
	{
		var cacheKey = 'api_bootstrap_data';
		cache.get(cacheKey, function (err, data) {
			if (data) {
				console.log('bootstrap data loaded from cache');
				// if data is set -> set vars and call callback 
				setAccessToken(data.data.access_token);
				setBootstrapData(data.data);
				callback();

			} else {
				console.log(' load bootstrap data from api');
				// if no data is set -> get data from remote, set vars, set cache, call callback
				request(getRequestString(), function (error, response, body) {
					// console.log('getRequestString()');
					// console.log(getRequestString());
					// console.log('getRequestString()');
					// console.log(error);
					if (!error && response.statusCode == 200) {
						var data = JSON.parse(body);
						setAccessToken(data.data.access_token);
						// console.log(getRequestString());
						// console.log(accessToken);
						setBootstrapData(data.data);

						// setting cache
						// console.log(' write bootstrap data to cache');
						cache.set(cacheKey, data, 60*10, function (err) { 
							if (err) {
								console.log(err);
							}
						});
						// call callback function
						callback();
					}
				});

			};


		});
		
	},
}

module.exports = Bootstrap;
